import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'             the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },
  {
    path: '/',
    redirect:  {
        path: '/main/main'
    }
  },
  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  }
]
// export const constantRoutes = [{
//   path: '/',
//   redirect: '/upms',
// }]
const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter () {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}
export const asyncRoutes = {
  Layout: Layout,
  // 首页
  main: () => import('@/views/main/index'),
  // 系统日志
  journal: () => import('@/views/journal/index'),
  // 乐团管理
  teamDetail: () => import('@/views/teamDetail/teamList'),
  // VIP管理
  vipList: () => import('@/views/vipClass/vipList'),
  // 教师管理
  teacherList: () => import('@/views/teacherManager/teacherList'),
  // 老师详情
  teacherDetail: () => import('@/views/teacherManager/teacherDetail/index'),
  // 学员管理
  studentList: () => import('@/views/studentManager/studentList'),
  // 学员详情
  studentDetail: () => import('@/views/studentManager/index'),
  // 订单管理
  orderList: () => import('@/views/businessManager/orderManager/index'),
  // 收入
  income: () => import('@/views/businessManager/orderManager/income'),
  // 退费订单
  backOrder: () => import('@/views/businessManager/orderManager/backMoney'),
  // 支出
  expend: () => import('@/views/businessManager/orderManager/expend'),
  // 商品管理
  shopManager: () => import('@/views/businessManager/shopManager/shopList'),
  // 商品修改（添加）
  shopOperation: () => import('@/views/businessManager/shopManager/shopOperation'),
  // 商品类型管理
  shopCategory: () => import('@/views/businessManager/shopManager/shopCategory'),
  // 报表中心
  reportForm: () => import('@/views/reportForm/index'),
  musicalManager: () => import('@/views/categroyManager/specialSetup/musicalManager'),
  // 系统管理
  specialSetup: () => import('@/views/categroyManager/specialSetup/index'),
  typesManager: () => import('@/views/categroyManager/specialSetup/typesManager'),
  tryClass: () => import('@/views/categroyManager/specialSetup/tryClass'),
  activityManager: () => import('@/views/categroyManager/specialSetup/activityManager'),
  tempalteManager: () => import('@/views/categroyManager/specialSetup/tempalteManager'),
  bannerManager: () => import('@/views/categroyManager/specialSetup/bannerManager'),
  holidayManager: () => import('@/views/categroyManager/specialSetup/holidayManager'),
  branchSetting: () => import('@/views/categroyManager/specialSetup/branchSetting'),
  jobTemplateSetting: () => import('@/views/categroyManager/specialSetup/jobTemplateSetting'),
  generalSettings: () => import('@/views/categroyManager/generalSettings/index'),
  siginManager: () => import('@/views/categroyManager/generalSettings/siginManager'),
  leaveManager: () => import('@/views/categroyManager/generalSettings/leaveManager'),
  cycleManager: () => import('@/views/categroyManager/generalSettings/cycleManager'),
  overallManager: () => import('@/views/categroyManager/generalSettings/overallManager'),
  payManager: () => import('@/views/categroyManager/generalSettings/payManager'),
  insideSetting: () => import('@/views/categroyManager/insideSetting/index'),
  adminManager: () => import('@/views/categroyManager/insideSetting/adminManager'),
  adminOperation: () => import('@/views/categroyManager/insideSetting/adminOperation'),
  staffManager: () => import('@/views/categroyManager/insideSetting/staffManager'),
  branchManager: () => import('@/views/categroyManager/insideSetting/branchManager'),
  addressManager: () => import('@/views/categroyManager/insideSetting/addressManager'),
  branchActive: () => import('@/views/categroyManager/insideSetting/branchActive'),
  branchActiveOperation: () => import('@/views/categroyManager/insideSetting/branchActiveOperation'),
  vipChargeSeting: () => import('@/views/categroyManager/vipChargeSeting'),
  vipActiveList: () => import('@/views/categroyManager/vipActiveList'),
  vipNewActive: () => import('@/views/categroyManager/vipNewActive'),
  vipParameterManager: () => import('@/views/categroyManager/generalSettings/vipParameterManager'),
  globalConfig: () => import('@/views/categroyManager/globalConfig'),
  // 侧边栏管理
  setSilder: () => import('@/views/setSilder/addSilder'), 

}
export default router
